--
-- Copyright (C) 199  Jim Bean
-- All rights reserved.
--
-- This software may be freely copied, modified, and redistributed
-- provided that this copyright notice is preserved on all copies.
--
-- There is no warranty or other guarantee of fitness of this software
-- for any purpose.  It is provided solely "as is".
--
--
--**************************************************************************
--
--  adcpulse.adb
--
--  This program is used to pulse the Computer Boards Inc.
--  CIO-DAS1400 Anolog to Digital Linux loadable module(adc).
--
--**************************************************************************/

with Ada.Text_IO; use Ada.TEXT_IO;

with ADC_Lib;

--**************************************************************************
--  Main
--**************************************************************************/

procedure Adcpulse is

   package Integer_Text_IO is new Ada.Text_IO.Integer_IO (Integer);
   package Float_Text_IO is new Ada.Text_IO.Float_IO (Float);
   use Integer_Text_IO, Float_Text_IO;

   Gain_Select : Integer := 0;
   Mode        : Integer := 0; -- ADC_SOFT_TRIGGER;
   Count       : Integer := 1;
   NoStop      : Integer := 0;
   Freq        : Integer := 100000;
   Real        : Integer := 1;
   Chans       : Integer := 1;
   dmalen      : Integer := 0;

   Data   : ADC_Lib.Word_Array  (0..2047);
   RData  : ADC_Lib.Float_Array (0..2047);
   Channel: ADC_Lib.Int_Array   (0..2047);
   Fd: Integer;
   Batch: Integer;
   Samples_Read: Integer;

begin

   Count := 1;
   Chans := 3;
   Freq  := 100;
   Dmalen := 2048;	
   -- Open the device file for the counter.

   fd := ADC_Lib.adcopen_1402_16 (Mode, Freq, Gain_Select, Chans, dmalen);

   if Count > 512 then Batch := 512;
                  else Batch := Count; end if;

   Samples_Read := 0;
   while Samples_Read < 300 loop

      Samples_Read := Samples_Read + ADC_Lib.ADC_read (fd, Data, Batch);

      ADC_Lib.Convert_Data (Long_Integer (Samples_Read), Data, Channel);

      ADC_Lib.Raw_To_Real  (Long_Integer (Samples_Read), Data, RData);

      for I in 0..Chans - 1 loop
         Put ("Sample "); Put (I,5); Put (" ="); Put (Integer (Data (I)),6);
         Put (" ==>"); Put (RData (I)); Put (", Channel =");
         Put (Integer (Channel (I)),3); New_Line;
      end loop;

      delay 0.1;

   end loop;

   Put (Samples_Read, 6); Put_Line (" Samples Read.");

   ADC_Lib.ADC_close (fd);

end ADCPulse;
