/*
 * Copyright (C) 1995  Sam Moore, Warren Jasper
 * Copyright (C) 1996  Joerg Weule
 * All rights reserved.
 *
 * This software may be freely copied, modified, and redistributed
 * provided that this copyright notice is preserved on all copies.
 *
 * You may not distribute this software, in whole or in part, as part of
 * any commercial product without the express consent of the authors.
 *
 * There is no warranty or other guarantee of fitness of this software
 * for any purpose.  It is provided solely "as is".
 *
 */

/***************************************************************************
 *
 *  adcsample.c
 *
 *  This program is used to test the Computer Boards Inc.
 *  CIO-DAS1400 Anolog to Digital Linux loadable module(adc).
 *
 ***************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <sys/types.h>
#include "adc.h"
#include "adclib.h"

/***************************************************************************
 *
 *  Global Data
 *
 ***************************************************************************/

int  Gain_Select = UP_10_00V;
int  Mode        = ADC_PACER_CLOCK;
int  Count       = 1;
int  NoStop      = 0;
int  Print       = 1;
int  Freq        = 100000;
int  Bits_12     = 0;
int  Bd_1402     = 1;
int  Chans       = 1;
int  dmalen      = 0;


/***************************************************************************
 *
 *  Show user how the command line is used.
 *
 ***************************************************************************/

void Usage( void )
{
    fprintf(stderr, "\n\
Usage: adcsample \'options\'\n\
Options:\n\
              [-range (0-3)]      - Voltage gain(see manual)\n
              [-ct ##]           - Number of samples to read\n
              [-soft]            - Use software triggers\n
              [-extern]          - Use external clock triggers\n
              [-pacer]           - Use pacer clock triggers\n
              [-dash12]          - 1400/12 -  12 bit conversion
              [-dash16]          - 1400/16 -  16 bit conversion
              [-1401]            - DAS1401 board
              [-1402]            - DAS1402 board
              [-noprint]         - Don't print samples\n
              [-nostop]          - Sample forever\n
              [-dmalen ##]       - length of DMA\n
              [-chans ##]        - number of channels\n
              [-freq ##]         - Sample Frequency used with pacer triggers\n
\n");
    exit(1);
}

/***************************************************************************
 *
 *  Process command line switches
 *
 ***************************************************************************/

void DoCommandLine(int argc, char **argv)
{
int i;

i = 1;

while (i < argc) {
  if (strcmp(argv[i], "-range") == 0) {
    i++;
    if (i == argc)
      Usage();
    else 
      Gain_Select = atoi(argv[i]);
  } else if (strcmp(argv[i], "-ct") == 0) {
    i++;
    if (i == argc)
      Usage();
    else 
      Count = atoi(argv[i]);
  } else if (strcmp(argv[i], "-soft") == 0) {
    Mode = ADC_SOFT_TRIGGER;
  } else if (strcmp(argv[i], "-pacer") == 0) {
    Mode = ADC_PACER_CLOCK;
  } else if (strcmp(argv[i], "-extern") == 0) {
    Mode = ADC_EXTERNAL_TRIGGER;
  } else if (strcmp(argv[i], "-noprint") == 0) {
    Print = 0;
  } else if (strcmp(argv[i], "-print") == 0) {
    Print = 1;
  } else if (strcmp(argv[i], "-dash16") == 0) {
    Bits_12 = 0;
  } else if (strcmp(argv[i], "-dash12") == 0) {
    Bits_12 = 1;
  } else if (strcmp(argv[i], "-1401") == 0) {
    Bd_1402 = 0;
  } else if (strcmp(argv[i], "-1402") == 0) {
    Bd_1402 = 1;
  } else if (strcmp(argv[i], "-nostop") == 0) {
    NoStop = 1;
  } else if (strcmp(argv[i], "-chans") == 0) {
    i++;
    if (i == argc)
      Usage();
    else 
      Chans = atoi(argv[i]);
  } else if (strcmp(argv[i], "-freq") == 0) {
    i++;
    if (i == argc)
      Usage();
    else 
      Freq = atoi(argv[i]);
  } else if (strcmp(argv[i], "-dmalen") == 0) {
    i++;
    if (i == argc)
      Usage();
    else 
      dmalen = atoi(argv[i]);
  } else {
    Usage();
  }
  i++;
}

}

/***************************************************************************
 *
 *  Main
 *
 ***************************************************************************/

int main(int argc, char **argv) {

  int   i;
  int	fd;
  int   Batch;
  WORD  data    [2048];
  float rdata   [2048];
  int   Channel [2048];
  int   SamplesRead = 1;

  DoCommandLine(argc, argv);
	
  /* Open the device file for the counter  */

  if (Bd_1402 == 1) {
    if (Bits_12) fd = adcopen_1402_12 (Mode, Freq, Gain_Select, Chans, dmalen);
    else         fd = adcopen_1402_16 (Mode, Freq, Gain_Select, Chans, dmalen);
  } else {
    if (Bits_12) fd = adcopen_1401_12 (Mode, Freq, Gain_Select, Chans, dmalen);
    else {
       printf ("There is no 16 bit version of the DAS-1401");
       exit (2);
    }
  }

  if (Count > 512) Batch = 512;
  else             Batch = Count;

  SamplesRead = 0;
  do {

    SamplesRead += adcread (fd, data, Batch);

    if ( 0==Print ) printf("main() in adcsample.c: read()= %d \n",SamplesRead);
    else {

      ConvertData (SamplesRead, data, Channel);

      RawToReal (SamplesRead, data, rdata);

      for (i = 0; i < SamplesRead; i++){ 
        printf("Sample %6d = (%5d) 0x%4x ==> %9.5f , Channel = %d\n",
          i, data[i], data[i], rdata[i], Channel[i]);
      }
    }
  } while (SamplesRead <= Count);

  printf("%d samples read\n", SamplesRead);

  adclose(fd);

  return 0;
}
