/* adctime.c, M. Welsh (mdw@cs.cornell.edu)
 * Simple program to read samples from DAS1200 board and time
 * acquisition rate.
 *
 * (c)1995 M. Welsh
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 */

/* See adctest.c and adcgraph.c for more complete code which
 * drives this board. This is used only as a simple tool to
 * gauge the performance of the driver. 
 */

#include <sys/types.h>
#include <sys/time.h>
#include <unistd.h>
#include <stdio.h>
#include <fcntl.h>
#include <assert.h>
#include <stdlib.h>
#include <malloc.h>
#include "adc.h"
#include "adclib.h"

int main(int argc, char **argv) {

  int const Freq = 100000;
  int const Chan = 16;
  WORD  data    [4096];
  int   Batch;
  int   Calls;
  int   fd;
  int   SamplesRead;
  struct timeval tv1, tv2;
  unsigned long Time, calc;

  int Datasets;

  if (argc != 2) {
  	fprintf(stderr,"Usage: %s <Datasets>\n",argv[0]);
  	exit(-1);
  }

  Datasets = atoi(argv[1]);

  /* 4096 words of 16 chans gives 256 datasets */
  if (Datasets > 256) Batch = 256;
  else                Batch = Datasets;

  fd = adcopen_1402_16 (ADC_PACER_CLOCK, Freq, UP_10_00V, Chan, 0);
  if (fd < 0) {
	perror("open");
	exit(-1);
  }

  Calls = 0;
  SamplesRead = 0;
  do {

     gettimeofday (&tv1,NULL);
     SamplesRead += adcread  (fd, data, Batch);
     Calls++;
     gettimeofday (&tv2,NULL);
     calc = (1e6*(tv2.tv_sec - tv1.tv_sec)) + (tv2.tv_usec - tv1.tv_usec);
     Time += calc;

  } while (SamplesRead <= Datasets);

  adclose(fd);
     
  printf("Time for %d samples: %lu usec: %f samples/sec\n",
         Datasets,Time,(float)((float)Datasets)/((float)Time*1e-6));


  printf("%d Calls\n", Calls);
  printf("%d samples read\n", SamplesRead);

  return 0;

}
